package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Apr 30, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Resolve returns the block for a module, using cache if fresh, running it if stale.
type Entry struct {
Text string `json:"text"`
Status *block.Status `json:"status,omitempty"`
FetchedAt time.Time `json:"fetched_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.